tta
===

.. image:: https://pypip.in/v/tta/badge.png
    :target: https://pypi.python.org/pypi/tta
    :alt: Latest PyPI version

Time Tracker Autocompleter for Muranosoft

This tool automatically fill out Time Tracker with messages from your git log.

Installation
------------

Install Python: `OSX <http://docs.python-guide.org/en/latest/starting/install/osx/>`_. `Windows <http://docs.python-guide.org/en/latest/starting/install/win/>`_. `Linux <http://docs.python-guide.org/en/latest/starting/install/linux/>`_.

Install tta, run console command:

.. code::
    
    pip install tta

Usage
-----

Type this command in console (in folder with your git repo):

.. code::

    tta -u uase -p qwerty -e gmail@gmail.com

* uase - Your usernme in Time Tracker
* password - Your password in Time Tracker
* gmail@gmail.com - Your email in git config

`tta` was written by `Kirill Ermolov <erm0l0v@ya.ru>`_.
